// Copyright 2016 Orus.io. All rights reserved.

package model

import (
	"github.com/m4rw3r/uuid"

	"bitbucket.org/orus-io/go-xbus/api"
	"bitbucket.org/orus-io/xbus/storage"
)

//go:generate yago --fmt

// Envelope represents a transaction, it is emitted by one emitter and is
// always started Open. Once the emitter sends the end_envelope event for
// this envelopeID it becomes closed.
//yago:autoattrs
type Envelope struct {
	Base
	TypesKnown bool
	Status     storage.EnvelopeStorageReceptionStatus `yago:"textmarshaled"`
	Error      string
}

// Event definitions
//yago:autoattrs
type Event struct {
	ID         int64     `yago:"primary_key,auto_increment"`
	EnvelopeID uuid.UUID `yago:"fk=Envelope ONDELETE CASCADE,unique_index=eventid"`
	EventID    uuid.UUID `yago:"unique_index=eventid"`
	EventType  string
	Status     storage.EnvelopeStorageReceptionStatus `yago:"textmarshaled"`
	ItemCount  uint64
	Checksum   api.Checksum `yago:"type=qb.Int().Unsigned()"`
	Validator  string
}

// Item that can be stuffed into an event
//yago:
type Item struct {
	ID      int64  `yago:"primary_key,auto_increment"`
	EventID int64  `yago:"fk=Event ONDELETE CASCADE,index=eventid_index_"`
	Batch   uint64 `yago:"."`
	Index   int64  `yago:"index_,index=eventid_index_"`
	Data    []byte `yago:"type=qb.Blob()"`
}
