// Copyright 2016 Orus.io. All rights reserved.

package model

import (
	"github.com/orus-io/yago"
)

// Model of the database
type Model struct {
	Meta *yago.Metadata

	Account         AccountModel
	Actor           ActorModel
	Envelope        EnvelopeModel
	Event           EventModel
	Item            ItemModel
	Process         ProcessModel
	ProcessLogEntry ProcessLogEntryModel
	ProcessState    ProcessStateModel
	Route           RouteModel
	RouteTarget     RouteTargetModel
	Pipeline        PipelineModel
	GraphNode       GraphNodeModel
	Job             JobModel
	LogEntry        LogEntryModel
}

// NewModel initialize a new Model
func NewModel() *Model {
	meta := yago.NewMetadata()
	return &Model{
		Meta:            meta,
		Account:         NewAccountModel(meta),
		Actor:           NewActorModel(meta),
		Envelope:        NewEnvelopeModel(meta),
		Event:           NewEventModel(meta),
		Item:            NewItemModel(meta),
		Process:         NewProcessModel(meta),
		ProcessLogEntry: NewProcessLogEntryModel(meta),
		ProcessState:    NewProcessStateModel(meta),
		Route:           NewRouteModel(meta),
		RouteTarget:     NewRouteTargetModel(meta),
		Pipeline:        NewPipelineModel(meta),
		GraphNode:       NewGraphNodeModel(meta),
		Job:             NewJobModel(meta),
		LogEntry:        NewLogEntryModel(meta),
	}
}
